@@ -3,8 +3,8 @@ import logging
 import os
 import sys
 
-import colorama
-from colorama import Fore, Style
+import requests
+from colorama import Fore, Style, init
 from colorama.ansi import clear_screen
 
 import grayskull
@@ -13,7 +13,7 @@ from grayskull.cli import CLIConfig
 from grayskull.cli.parser import parse_pkg_name_version
 from grayskull.cli.stdout import print_msg
 
-colorama.init(autoreset=True)
+init(autoreset=True)
 logging.basicConfig(format="%(levelname)s:%(message)s")
 
 
@@ -80,6 +80,13 @@ def main(args=None):
         dest="list_missing_deps",
         help="After the execution Grayskull will print all the missing dependencies.",
     )
+    pypi_cmds.add_argument(
+        "--strict-conda-forge",
+        default=False,
+        action="store_true",
+        dest="is_strict_conda_forge",
+        help="It will generate the recipes strict for the conda-forge channel.",
+    )
 
     args = parser.parse_args(args)
 
@@ -110,9 +117,19 @@ def main(args=None):
             f"{Fore.BLUE}{pkg_name} (pypi) {Fore.GREEN}####\n"
         )
         pkg_name, pkg_version = parse_pkg_name_version(pkg_name)
-        recipe = GrayskullFactory.create_recipe(
-            "pypi", pkg_name, pkg_version, download=args.download
-        )
+        try:
+            recipe = GrayskullFactory.create_recipe(
+                "pypi",
+                pkg_name,
+                pkg_version,
+                download=args.download,
+                is_strict_cf=args.is_strict_conda_forge,
+            )
+        except requests.exceptions.HTTPError as err:
+            print_msg(
+                f"{Fore.RED}Package seems to be missing on pypi.\nException: {err}\n\n"
+            )
+            continue
         recipe.generate_recipe(args.output, mantainers=args.maintainers)
         print_msg(
             f"\n{Fore.GREEN}#### Recipe generated on "
