@@ -4,6 +4,8 @@ import subprocess
 import requests
 from colorama import Fore
 
+from grayskull.cli.stdout import print_msg
+
 log = logging.getLogger(__name__)
 
 
@@ -19,17 +21,15 @@ def get_git_current_user_metadata() -> dict:
 def get_git_current_user() -> str:
     try:
         github_search = get_git_current_user_metadata()
-        if github_search["total_count"] == 1:
-            login_github = github_search["items"][0]["login"]
-            return login_github
+        if github_search["total_count"] >= 1:
+            return github_search["items"][0]["login"]
     except Exception as err:
         log.debug(
             f"Exception occurred when trying to recover user information from github."
             f" Exception: {err}"
         )
-        pass
-    print(
-        f"{Fore.LIGHTBLACK_EX}Using default recipe maintainer:"
+    print_msg(
+        f"Using default recipe maintainer:"
         f" {Fore.LIGHTMAGENTA_EX}AddYourGitHubIdHere"
     )
     return "AddYourGitHubIdHere"
