@@ -13,7 +13,6 @@ from typing import List, Optional, Union
 import requests
 from rapidfuzz import process
 from rapidfuzz.fuzz import token_set_ratio, token_sort_ratio
-from requests import HTTPError
 
 from grayskull.cli.stdout import print_msg
 from grayskull.license.data import get_all_licenses  # noqa
@@ -40,7 +39,7 @@ def get_all_licenses_from_spdx() -> List:
         f" response: {response}"
     )
     if response.status_code != 200:
-        raise HTTPError(
+        raise requests.HTTPError(
             f"It was not possible to communicate with spdx api.\n{response.text}"
         )
     print_msg("Recovering license info from spdx.org ...")
@@ -211,6 +210,8 @@ def search_license_api_github(
     :param default: default license type
     :return: License information
     """
+    if github_url.endswith("/"):
+        github_url = github_url[:-1]
     github_url = _get_api_github_url(github_url, version)
     log.info(f"Github url: {github_url} - recovering license info")
     print_msg("Recovering license information from github...")
@@ -257,6 +258,8 @@ def search_license_folder(
         r"(\bcopyright\b|\blicense[s]*\b|\bcopying\b|\bcopyleft\b)", re.IGNORECASE
     )
     for folder_path, _, filenames in os.walk(str(path)):
+        if os.path.basename(folder_path).startswith("."):
+            continue
         for one_file in filenames:
             if re_search.match(one_file):
                 lc_path = os.path.join(folder_path, one_file)
@@ -285,6 +288,8 @@ def search_license_repo(
             f"Exception occurred when gs was trying to clone the repository."
             f" url: {git_url}, version: {version}. Exception: {err}"
         )
+        if not version.startswith("v"):
+            return search_license_repo(git_url, f"v{version}", default)
         return None
     return search_license_folder(str(tmp_dir), default)
 
