@@ -4,7 +4,6 @@ import os
 import re
 import shutil
 import sys
-import traceback
 from collections import namedtuple
 from contextlib import contextmanager
 from copy import deepcopy
@@ -14,10 +13,10 @@ from pathlib import Path
 from subprocess import check_output
 from tempfile import mkdtemp
 from typing import Dict, List, Optional, Tuple, Union
+from urllib.parse import urlparse
 
 import requests
 from colorama import Fore, Style
-from requests import HTTPError
 
 from grayskull.base.base_recipe import AbstractRecipeModel
 from grayskull.base.pkg_info import is_pkg_available
@@ -34,6 +33,7 @@ from grayskull.utils import get_vendored_dependencies
 log = logging.getLogger(__name__)
 PyVer = namedtuple("PyVer", ["major", "minor"])
 SUPPORTED_PY = sorted([PyVer(2, 7), PyVer(3, 6), PyVer(3, 7), PyVer(3, 8)])
+CONDA_FORGE_STRICT = sorted([PyVer(3, 6), PyVer(3, 7), PyVer(3, 8)])
 
 
 class PyPi(AbstractRecipeModel):
@@ -49,11 +49,13 @@ class PyPi(AbstractRecipeModel):
         name: Optional[str] = None,
         version: Optional[str] = None,
         download: bool = False,
+        is_strict_cf: bool = False,
     ):
         self._download = download
+        self._is_strict_cf = is_strict_cf
         self._setup_metadata = None
         self._is_arch = False
-        super(PyPi, self).__init__(name=name, version=version)
+        super(PyPi, self).__init__(name=name, version=str(version) if version else None)
         self["build"]["script"] = "<{ PYTHON }} -m pip install . -vv"
 
     @staticmethod
@@ -213,6 +215,27 @@ class PyPi(AbstractRecipeModel):
         def __fake_distutils_setup(*args, **kwargs):
             if not isinstance(kwargs, dict) or not kwargs:
                 return
+
+            def _fix_list_requirements(key_deps: str) -> List:
+                """Fix when dependencies have lists inside of another sequence"""
+                val_deps = kwargs.get(key_deps)
+                if not val_deps:
+                    return val_deps
+                list_req = []
+                if isinstance(val_deps, str):
+                    val_deps = [val_deps]
+                for val in val_deps:
+                    if isinstance(val, (tuple, list)):
+                        list_req.extend(list(map(str, val)))
+                    else:
+                        list_req.append(str(val))
+                return list_req
+
+            if "setup_requires" in kwargs:
+                kwargs["setup_requires"] = _fix_list_requirements("setup_requires")
+            if "install_requires" in kwargs:
+                kwargs["install_requires"] = _fix_list_requirements("install_requires")
+
             data_dist.update(kwargs)
             if not data_dist.get("setup_requires"):
                 data_dist["setup_requires"] = []
@@ -255,11 +278,8 @@ class PyPi(AbstractRecipeModel):
                 )
                 PyPi.__run_setup_py(path_setup, data_dist, run_py=True)
             yield data_dist
-        except:  # noqa
-            log.debug(
-                "Exception occurred when executing sdist injection:"
-                f" {traceback.format_exc()}"
-            )
+        except BaseException as err:
+            log.debug(f"Exception occurred when executing sdist injection: {err}")
             yield data_dist
         finally:
             core.setup = setup_core_original
@@ -346,7 +366,16 @@ class PyPi(AbstractRecipeModel):
         if dep_name == "pkg_resources":
             dep_name = "setuptools"
         try:
-            check_output(["pip", "install", dep_name, f"--target={pip_dir}"])
+            check_output(
+                [
+                    sys.executable,
+                    "-m",
+                    "pip",
+                    "install",
+                    dep_name,
+                    f"--target={pip_dir}",
+                ]
+            )
         except Exception as err:
             log.error(
                 f"It was not possible to install {dep_name}.\n"
@@ -374,12 +403,15 @@ class PyPi(AbstractRecipeModel):
             return pypi_metadata.get(key) or sdist_metadata.get(key)
 
         requires_dist = PyPi._merge_requires_dist(pypi_metadata, sdist_metadata)
+        all_packages_names = get_val("packages")
+        if not all_packages_names:
+            all_packages_names = get_val("py_modules")
         return {
             "author": get_val("author"),
             "name": get_val("name"),
             "version": get_val("version"),
             "source": pypi_metadata.get("source"),
-            "packages": get_val("packages"),
+            "packages": all_packages_names,
             "url": get_val("url"),
             "classifiers": get_val("classifiers"),
             "compilers": PyPi._get_compilers(requires_dist, sdist_metadata),
@@ -440,7 +472,10 @@ class PyPi(AbstractRecipeModel):
                 if isinstance(gui_scripts, str):
                     gui_scripts = [gui_scripts]
                 entry_points_result += gui_scripts
-            return entry_points_result
+            return_entry_point = []
+            for entry_point in entry_points_result:
+                return_entry_point.extend(entry_point.split("\n"))
+            return [ep for ep in return_entry_point if ep.strip()]
         return []
 
     @staticmethod
@@ -544,6 +579,13 @@ class PyPi(AbstractRecipeModel):
         all_requirements["run"] = solve_list_pkg_name(
             all_requirements["run"], self.PYPI_CONFIG
         )
+        if self._is_strict_cf:
+            all_requirements["host"] = clean_deps_for_conda_forge(
+                all_requirements["host"]
+            )
+            all_requirements["run"] = clean_deps_for_conda_forge(
+                all_requirements["run"]
+            )
         print_requirements(all_requirements)
 
         test_entry_points = PyPi._get_test_entry_points(metadata.get("entry_points"))
@@ -601,10 +643,13 @@ class PyPi(AbstractRecipeModel):
         the license.
         """
         git_url = metadata.get("dev_url", None)
-        if not git_url and "github.com/" in metadata.get("project_url", ""):
+        if (
+            not git_url
+            and "github.com" == urlparse(metadata.get("project_url", "")).netloc
+        ):
             git_url = metadata.get("project_url")
         # "url" is always present but sometimes set to None
-        if not git_url and "github.com/" in (metadata.get("url") or ""):
+        if not git_url and "github.com" == urlparse((metadata.get("url") or "")).netloc:
             git_url = metadata.get("url")
 
         short_license = search_license_file(
@@ -634,7 +679,7 @@ class PyPi(AbstractRecipeModel):
 
         metadata = requests.get(url=url_pypi, timeout=5)
         if metadata.status_code != 200:
-            raise HTTPError(
+            raise requests.HTTPError(
                 f"It was not possible to recover PyPi metadata for {name}.\n"
                 f"Error code: {metadata.status_code}"
             )
@@ -664,12 +709,32 @@ class PyPi(AbstractRecipeModel):
             "license": info.get("license"),
             "source": {
                 "url": "https://pypi.io/packages/source/{{ name[0] }}/{{ name }}/"
-                "{{ name }}-{{ version }}.tar.gz",
+                f"{PyPi._get_url_filename(metadata)}",
                 "sha256": PyPi.get_sha256_from_pypi_metadata(metadata),
             },
             "sdist_url": PyPi._get_sdist_url_from_pypi(metadata),
         }
 
+    @staticmethod
+    def _get_url_filename(metadata: dict, default: Optional[str] = None) -> str:
+        """Method responsible to get the filename and right extension to add
+        to the pypi url
+
+        :param metadata: Dictionary with the all package metadata filled
+        :param default: default value for the package filename
+        :return: filename and extension to download the file on pypi
+        """
+        if default is None:
+            default = "{{ name }}-{{ version }}.tar.gz"
+        if "urls" not in metadata:
+            return default
+
+        for pkg_url in metadata["urls"]:
+            if pkg_url["packagetype"] == "sdist":
+                version = metadata["info"]["version"]
+                return pkg_url["filename"].replace(version, "{{ version }}")
+        return default
+
     @staticmethod
     def _get_sdist_url_from_pypi(metadata: dict) -> str:
         """Return the sdist url looking for the pypi metadata
@@ -730,13 +795,17 @@ class PyPi(AbstractRecipeModel):
             self._is_arch = True
 
         if self._is_arch:
-            version_to_selector = PyPi.py_version_to_selector(metadata)
+            version_to_selector = PyPi.py_version_to_selector(
+                metadata, is_strict_cf=self._is_strict_cf
+            )
             if version_to_selector:
                 self["build"]["skip"] = True
                 self["build"]["skip"].values[0].selector = version_to_selector
             limit_python = ""
         else:
-            limit_python = PyPi.py_version_to_limit_python(metadata)
+            limit_python = PyPi.py_version_to_limit_python(
+                metadata, is_strict_cf=self._is_strict_cf
+            )
 
         limit_python = f" {limit_python}" if limit_python else ""
 
@@ -912,7 +981,7 @@ class PyPi(AbstractRecipeModel):
 
     @staticmethod
     def _generic_py_ver_to(
-        pypi_metadata: dict, is_selector: bool = False
+        pypi_metadata: dict, is_selector: bool = False, is_strict_cf: bool = False
     ) -> Optional[str]:
         """Generic function which abstract the parse of the requires_python
         present in the PyPi metadata. Basically it can generate the selectors
@@ -930,17 +999,18 @@ class PyPi(AbstractRecipeModel):
         if not req_python:
             return None
 
-        py_ver_enabled = PyPi._get_py_version_available(req_python)
+        py_ver_enabled = PyPi._get_py_version_available(
+            req_python, is_strict_cf=is_strict_cf
+        )
         small_py3_version = get_small_py3_version(list(py_ver_enabled.keys()))
         all_py = list(py_ver_enabled.values())
         if all(all_py):
             return None
-        if all(all_py[1:]):
-            return (
-                "# [py2k]"
-                if is_selector
-                else f">={small_py3_version.major}.{small_py3_version.minor}"
-            )
+        if all(all_py if is_strict_cf else all_py[1:]):
+            if is_selector:
+                return None if is_strict_cf else "# [py2k]"
+            else:
+                return f">={small_py3_version.major}.{small_py3_version.minor}"
         if py_ver_enabled.get(PyVer(2, 7)) and any(all_py[1:]) is False:
             return "# [py3k]" if is_selector else "<3.0"
 
@@ -956,7 +1026,7 @@ class PyPi(AbstractRecipeModel):
             elif any(all_py[pos:]) is False:
                 if is_selector:
                     py2k = ""
-                    if not all_py[0]:
+                    if not is_strict_cf and not all_py[0]:
                         py2k = " or py2k"
                     return f"# [py>={py_ver.major}{py_ver.minor}{py2k}]"
                 else:
@@ -966,7 +1036,7 @@ class PyPi(AbstractRecipeModel):
                     return f"{py2}<{py_ver.major}.{py_ver.minor}"
 
         all_selector = PyPi._get_py_multiple_selectors(
-            py_ver_enabled, is_selector=is_selector
+            py_ver_enabled, is_selector=is_selector, is_strict_cf=is_strict_cf
         )
         if all_selector:
             return (
@@ -977,23 +1047,31 @@ class PyPi(AbstractRecipeModel):
         return None
 
     @staticmethod
-    def py_version_to_limit_python(pypi_metadata: dict) -> Optional[str]:
-        return PyPi._generic_py_ver_to(pypi_metadata, is_selector=False)
+    def py_version_to_limit_python(
+        pypi_metadata: dict, is_strict_cf: bool = False
+    ) -> Optional[str]:
+        return PyPi._generic_py_ver_to(
+            pypi_metadata, is_selector=False, is_strict_cf=is_strict_cf
+        )
 
     @staticmethod
-    def py_version_to_selector(pypi_metadata: dict) -> Optional[str]:
-        return PyPi._generic_py_ver_to(pypi_metadata, is_selector=True)
+    def py_version_to_selector(
+        pypi_metadata: dict, is_strict_cf: bool = False
+    ) -> Optional[str]:
+        return PyPi._generic_py_ver_to(
+            pypi_metadata, is_selector=True, is_strict_cf=is_strict_cf
+        )
 
     @staticmethod
     def _get_py_version_available(
-        req_python: List[Tuple[str, str, str]]
+        req_python: List[Tuple[str, str, str]], is_strict_cf: bool = False
     ) -> Dict[PyVer, bool]:
         """Get the python version available given the requires python received
 
         :param req_python: Requires python
         :return: Dict of Python versions if it is enabled or disabled
         """
-        sup_python_ver = deepcopy(SUPPORTED_PY)
+        sup_python_ver = deepcopy(CONDA_FORGE_STRICT if is_strict_cf else SUPPORTED_PY)
         for _, major, minor in req_python:
             if not minor:
                 minor = 0
@@ -1016,23 +1094,27 @@ class PyPi(AbstractRecipeModel):
 
     @staticmethod
     def _get_py_multiple_selectors(
-        selectors: Dict[PyVer, bool], is_selector=False
+        selectors: Dict[PyVer, bool],
+        is_selector: bool = False,
+        is_strict_cf: bool = False,
     ) -> List:
         """Get python selectors available.
 
         :param selectors: Dict with the Python version and if it is selected
         :param is_selector: if it needs to convert to selector or constrain python
+        :param is_strict_cf: Enable or disable to generate recipes specific
+         to conda-forge
         :return: list with all selectors or constrained python
         """
         all_selector = []
-        if selectors[PyVer(2, 7)] is False:
+        if not is_strict_cf and selectors[PyVer(2, 7)] is False:
             all_selector += (
                 ["py2k"]
                 if is_selector
                 else get_small_py3_version(list(selectors.keys()))
             )
         for py_ver, is_enabled in selectors.items():
-            if py_ver == PyVer(2, 7) or is_enabled:
+            if (not is_strict_cf and py_ver == PyVer(2, 7)) or is_enabled:
                 continue
             all_selector += (
                 [f"py=={py_ver.major}{py_ver.minor}"]
@@ -1090,3 +1172,30 @@ def search_setup_root(path_folder: Union[Path, str]) -> Path:
     pyproject_toml = list(Path(path_folder).rglob("pyproject.toml"))
     if pyproject_toml:
         return pyproject_toml[0]
+
+
+def clean_deps_for_conda_forge(list_deps: List) -> List:
+    """Remove dependencies which conda-forge is not supporting anymore.
+    For example Python 2.7, Python version less than 3.6
+
+    :param list_deps: List of dependencies
+    :return: New list of dependencies
+    """
+    py_ver_min = CONDA_FORGE_STRICT[0]
+    re_delimiter = re.compile(r"#\s+\[py\s*(?:([<>=!]+))?\s*(\d+)\]\s*$", re.DOTALL)
+    result_deps = []
+    for dependency in list_deps:
+        match_del = re_delimiter.search(dependency)
+        if match_del is None:
+            result_deps.append(dependency)
+            continue
+        match_del = match_del.groups()
+        if not match_del[0]:
+            match_del = ("==", match_del[1])
+        major = int(match_del[1][0])
+        minor = int(match_del[1][1:].replace("k", "0"))
+        current_py = PyVer(major=major, minor=minor)
+        log.debug(f"Evaluating: {py_ver_min}{match_del}{current_py} -- {dependency}")
+        if eval(f"py_ver_min{match_del[0]}current_py"):
+            result_deps.append(dependency)
+    return result_deps
