@@ -8,6 +8,7 @@ from colorama import Fore, Style
 
 from grayskull.cli import CLIConfig
 from grayskull.pypi import PyPi
+from grayskull.pypi.pypi import clean_deps_for_conda_forge
 
 
 @pytest.fixture
@@ -41,10 +42,11 @@ def test_extract_pypi_requirements(pypi_metadata):
 
 
 def test_get_pypi_metadata(pypi_metadata):
-    recipe = PyPi(name="pytest", version="5.3.1")
+    recipe = PyPi(name="pytest", version="5.3.1", is_strict_cf=True)
     metadata = recipe._get_pypi_metadata(name="pytest", version="5.3.1")
     assert metadata["name"] == "pytest"
     assert metadata["version"] == "5.3.1"
+    assert "pathlib2 >=2.2.0  # [py<36]" not in recipe["requirements"]["run"]
 
 
 def test_get_name_version_from_requires_dist():
@@ -95,48 +97,63 @@ def test_get_selector():
 
 
 @pytest.mark.parametrize(
-    "requires_python, exp_selector",
+    "requires_python, exp_selector, ex_cf",
     [
-        (">=3.5", "2k"),
-        (">=3.6", "2k"),
-        (">=3.7", "<37"),
-        ("<=3.7", ">=38"),
-        ("<=3.7.1", ">=38"),
-        ("<3.7", ">=37"),
-        (">2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*", "<36"),
-        (">=2.7, !=3.6.*", "==36"),
-        (">3.7", "<38"),
-        (">2.7", "2k"),
-        ("<3", "3k"),
-        ("!=3.7", "==37"),
+        (">=3.5", "2k", None),
+        (">=3.6", "2k", None),
+        (">=3.7", "<37", "<37"),
+        ("<=3.7", ">=38", ">=38"),
+        ("<=3.7.1", ">=38", ">=38"),
+        ("<3.7", ">=37", ">=37"),
+        (">2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*", "<36", "<36"),
+        (">=2.7, !=3.6.*", "==36", "==36"),
+        (">3.7", "<38", "<38"),
+        (">2.7", "2k", "<36"),
+        ("<3", "3k", "skip"),
+        ("!=3.7", "==37", "==37"),
     ],
 )
-def test_py_version_to_selector(requires_python, exp_selector):
+def test_py_version_to_selector(requires_python, exp_selector, ex_cf):
     metadata = {"requires_python": requires_python}
     assert PyPi.py_version_to_selector(metadata) == f"# [py{exp_selector}]"
 
+    if ex_cf != "skip":
+        expected = f"# [py{ex_cf}]" if ex_cf else None
+        result = PyPi.py_version_to_selector(metadata, is_strict_cf=True)
+        if isinstance(expected, str):
+            assert expected == result
+        else:
+            assert expected is result
+
 
 @pytest.mark.parametrize(
-    "requires_python, exp_limit",
+    "requires_python, exp_limit, ex_cf",
     [
-        (">=3.5", ">=3.5"),
-        (">=3.6", ">=3.6"),
-        (">=3.7", ">=3.7"),
-        ("<=3.7", "<3.8"),
-        ("<=3.7.1", "<3.8"),
-        ("<3.7", "<3.7"),
-        (">2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*", ">=3.6"),
-        (">=2.7, !=3.6.*", "!=3.6"),
-        (">3.7", ">=3.8"),
-        (">2.7", ">=3.6"),
-        ("<3", "<3.0"),
-        ("!=3.7", "!=3.7"),
+        (">=3.5", ">=3.5", None),
+        (">=3.6", ">=3.6", None),
+        (">=3.7", ">=3.7", ">=3.7"),
+        ("<=3.7", "<3.8", "<3.8"),
+        ("<=3.7.1", "<3.8", "<3.8"),
+        ("<3.7", "<3.7", "<3.7"),
+        (">2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*", ">=3.6", ">=3.6"),
+        (">=2.7, !=3.6.*", "!=3.6", "!=3.6"),
+        (">3.7", ">=3.8", ">=3.8"),
+        (">2.7", ">=3.6", ">=3.6"),
+        ("<3", "<3.0", "skip"),
+        ("!=3.7", "!=3.7", "!=3.7"),
     ],
 )
-def test_py_version_to_limit_python(requires_python, exp_limit):
+def test_py_version_to_limit_python(requires_python, exp_limit, ex_cf):
     metadata = {"requires_python": requires_python}
     assert PyPi.py_version_to_limit_python(metadata) == f"{exp_limit}"
 
+    if ex_cf != "skip":
+        result = PyPi.py_version_to_limit_python(metadata, is_strict_cf=True)
+        if isinstance(ex_cf, str):
+            assert ex_cf == result
+        else:
+            assert ex_cf is result
+
 
 def test_get_sha256_from_pypi_metadata():
     metadata = {
@@ -209,6 +226,16 @@ def test_injection_distutils_compiler_gsw():
     assert data["packages"] == ["gsw"]
 
 
+def test_injection_distutils_setup_reqs_ensure_list():
+    pkg_name, pkg_ver = "pyinstaller-hooks-contrib", "2020.7"
+    recipe = PyPi(name=pkg_name, version=pkg_ver)
+    data = recipe._get_sdist_metadata(
+        f"https://pypi.io/packages/source/p/{pkg_name}/{pkg_name}-{pkg_ver}.tar.gz",
+        pkg_name,
+    )
+    assert data.get("setup_requires") == ["setuptools >= 30.3.0"]
+
+
 def test_merge_pypi_sdist_metadata():
     recipe = PyPi(name="gsw", version="3.3.1")
     pypi_metadata = recipe._get_pypi_metadata(name="gsw", version="3.3.1")
@@ -272,6 +299,16 @@ def test_get_entry_points_from_sdist():
             }
         )
     ) == sorted(["console_scripts=entrypoints"])
+    assert sorted(
+        PyPi._get_entry_points_from_sdist(
+            {
+                "entry_points": {
+                    "gui_scripts": None,
+                    "console_scripts": "console_scripts=entrypoints\nfoo=bar.main",
+                }
+            }
+        )
+    ) == sorted(["console_scripts=entrypoints", "foo=bar.main"])
     assert sorted(
         PyPi._get_entry_points_from_sdist(
             {
@@ -401,7 +438,7 @@ def test_zipp_recipe_tags_on_deps():
     assert recipe["requirements"]["host"] == [
         "pip",
         "python >=3.6",
-        "setuptools_scm >=3.4.1",
+        "setuptools-scm >=3.4.1",
     ]
 
 
@@ -430,8 +467,8 @@ def test_get_test_entry_points():
 
 def test_importlib_metadata_two_setuptools_scm():
     recipe = PyPi(name="importlib-metadata", version="1.5.0")
-    assert "setuptools_scm" in recipe["requirements"]["host"]
-    assert "setuptools-scm" not in recipe["requirements"]["host"]
+    assert "setuptools-scm" in recipe["requirements"]["host"]
+    assert "setuptools_scm" not in recipe["requirements"]["host"]
     assert recipe["about"]["license"] == "Apache-2.0"
 
 
@@ -546,3 +583,70 @@ def test_multiples_exit_setup():
     """Bug fix #146"""
     recipe = PyPi(name="pyproj", version="2.6.1")
     assert recipe
+
+
+def test_sequence_inside_another_in_dependencies():
+    recipe = PyPi(name="unittest2", version="1.1.0")
+    assert recipe["requirements"]["host"] == [
+        "argparse",
+        "pip",
+        "python",
+        "six >=1.4",
+        "traceback2",
+    ]
+    assert recipe["requirements"]["run"] == [
+        "argparse",
+        "python",
+        "six >=1.4",
+        "traceback2",
+    ]
+
+
+def test_recipe_with_just_py_modules():
+    recipe = PyPi(name="python-markdown-math", version="0.7")
+    assert recipe["test"]["imports"] == "mdx_math"
+
+
+def test_recipe_extension():
+    recipe = PyPi(name="azure-identity", version="1.3.1")
+    assert (
+        recipe["source"]["url"][0].value
+        == "https://pypi.io/packages/source/{{ name[0] }}/{{ name }}/"
+        "azure-identity-{{ version }}.zip"
+    )
+
+
+def test_get_url_filename():
+    assert PyPi._get_url_filename({}) == "{{ name }}-{{ version }}.tar.gz"
+    assert PyPi._get_url_filename({}, "default") == "default"
+    assert (
+        PyPi._get_url_filename({"urls": [{"packagetype": "nothing"}]})
+        == "{{ name }}-{{ version }}.tar.gz"
+    )
+    assert (
+        PyPi._get_url_filename({"urls": [{"packagetype": "nothing"}]}, "default")
+        == "default"
+    )
+    assert (
+        PyPi._get_url_filename(
+            {
+                "info": {"version": "1.2.3"},
+                "urls": [{"packagetype": "sdist", "filename": "foo_file-1.2.3.zip"}],
+            }
+        )
+        == "foo_file-{{ version }}.zip"
+    )
+
+
+def test_clean_deps_for_conda_forge():
+    assert clean_deps_for_conda_forge(["deps1", "deps2  # [py34]"]) == ["deps1"]
+    assert clean_deps_for_conda_forge(["deps1", "deps2  # [py<34]"]) == ["deps1"]
+    assert clean_deps_for_conda_forge(["deps1", "deps2  # [py<38]"]) == [
+        "deps1",
+        "deps2  # [py<38]",
+    ]
+
+
+def test_empty_entry_points():
+    recipe = PyPi(name="modulegraph", version="0.18")
+    assert recipe["build"]["entry_points"] == "modulegraph = modulegraph.__main__:main"
